@@ -14,7 +14,7 @@ class Formatter:
         if naming.find('_') != -1 and naming[0].isupper():
             return naming[0].lower() + naming[1:]
         components = naming.split('_')
-        return components[0] + ''.join(x[0].capitalize() + x[1:] for x in components[1:])
+        return components[0].lower() + ''.join(x[0].capitalize() + x[1:] for x in components[1:])
 
     @staticmethod
     def __is_not_lower_camel_case(naming):
@@ -65,7 +65,6 @@ class Formatter:
         return count
 
     def __fix_namings(self):
-        stack = []
         i = 0
         while i < len(self.__tokens):
             token = self.__tokens[i]
@@ -92,7 +91,6 @@ class Formatter:
                 if token.get_value() == 'object' and self.__tokens[i - 2].get_value() == 'package':
                     i = self.__fix_packages(i) - 1
                     continue
-                stack.append(token.get_value())
                 i = self.__fix_class_trait_object(i) - 1
             elif token.get_token_type() == TokenType.IDENTIFIER and token.get_fixed_value() is None and \
                     Formatter.__is_not_lower_camel_case(token.get_value()):
